@@ -253,14 +253,40 @@ async def process_create_vote_account(val_keypair, log_level: int = 0):
     payer_keypair = parse_keypair_input(f"./{val_keypair}")
     global_gem_pubkey, _global_gem_bump = PublicKey.find_program_address([bytes(ingl_constants.GLOBAL_GEM_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
     gem_info = await client.get_account_info(global_gem_pubkey)
-    numeration = GlobalGems.parse(gem_info.value.data).proposal_numeration
-    if not GlobalGems.is_proposal_ongoing:
+    global_gems = GlobalGems.parse(gem_info.value.data)
+    numeration = global_gems.proposal_numeration
+    if not global_gems.is_proposal_ongoing:
         client.close
         print("[warning]A Validator Selection Proposal is not ongoing!!![/warning]")
     t_dets = await create_vote_account(payer_keypair, numeration-1, client, log_level)
     print(t_dets)
     await client.close()
 
+@click.command(name='vote_validator')
+@click.option('--keypair', default = 'keypair.json')
+@click.option('--log_level', default = '2')
+@click.argument('mint_id')
+@click.argument("validator_index")
+async def process_vote_validator_proposal(keypair, mint_id, validator_index, log_level: int = 0):
+    validator_index = int(validator_index)
+    log_level = int(log_level)
+    client = AsyncClient(rpc_url.target_network)
+    client_state = await client.is_connected()
+    print("Client is connected" if client_state else "Client is Disconnected")
+    payer_keypair = parse_keypair_input(f"./{keypair}")
+    mint_pubkey = parse_pubkey_input(mint_id)
+    global_gem_pubkey, _global_gem_bump = PublicKey.find_program_address([bytes(ingl_constants.GLOBAL_GEM_KEY, 'UTF-8')], ingl_constants.INGL_PROGRAM_ID)
+    gem_info = await client.get_account_info(global_gem_pubkey)
+    global_gems = GlobalGems.parse(gem_info.value.data)
+    numeration = global_gems.proposal_numeration
+    if not global_gems.is_proposal_ongoing:
+        client.close
+        print("[warning]A Validator Selection Proposal is not ongoing!!![/warning]")
+    t_dets = await vote_validator_proposal(payer_keypair, numeration-1, [mint_pubkey], validator_index, client, log_level)
+    print(t_dets)
+    await client.close()
+
+
 @click.command(name='create_upgrade_proposal')
 @click.argument('buffer')
 @click.argument('code_link')
@@ -362,8 +388,10 @@ entry.add_command(finalize_rebalancing)
 entry.add_command(ingl)
 entry.add_command(close_val_proposal)
 entry.add_command(process_vote_account_rewards)
-
+entry.add_command(process_allocate_gem)
+entry.add_command(process_deallocate_gem)
 entry.add_command(process_create_vote_account)
+entry.add_command(process_vote_validator_proposal)
 entry.add_command(get_vote_pubkey)
 entry.add_command(find_vote_key)
 entry.add_command(process_create_upgrade_proposal)
