@@ -289,7 +289,7 @@ async def create_validator_proposal(payer_keypair: KeypairInput, proposal_numera
     except Exception as e:
         return(f"[warning]Error: {e}[/warning]")
 
-async def vote_validator_proposal(payer_keypair: KeypairInput, proposal_numeration: int, mint_pubkeys: List[PublicKey], val_index:int, client: AsyncClient, log_level: int = 0) -> str:
+async def vote_validator_proposal(payer_keypair: KeypairInput, proposal_numeration: int, mint_pubkeys: List[PubkeyInput], val_index:int, client: AsyncClient, log_level: int = 0) -> str:
     proposal_pubkey, _proposal_bump = PublicKey.find_program_address([bytes(ingl_constants.PROPOSAL_KEY, 'UTF-8'), proposal_numeration.to_bytes(4,"big")], ingl_constants.INGL_PROGRAM_ID)
 
 
